@@ -265,25 +265,30 @@ plotSPC <- function(x, color='soil_color', width=0.2, name=NULL, label=idname(x)
       # If this is true this is a column of valid colors
       h$.color <- h[[color]]
     } else {
-      # Otherwise that means this is a factor
+      # Otherwise that means this is or can be converted into a factor
+      if(!is.factor(h[[color]]))
+        h[[color]] <- factor(h[[color]])
       
-      # Generate colour values
-      h$.color <- scales::col_factor(
+      # get color mapping levels after dropping missing levels
+      h[[color]] <- droplevels(h[[color]])
+      color.levels <- levels(h[[color]])
+      
+      # make a color mapping function
+      color.mapper <- scales::col_factor(
         palette = col.palette,
-        domain = NULL,
-        na.color = "#FFFFFF"
-      )(h[[color]])
-      
-      ## TODO: does this respect factor levels?
-      ## TODO: does not generate enough colors...?
-      # generate range / colors for legend
-      pretty.vals <- na.omit( unique( h[[color]] ) )
-      color.legend.data <- list(
-        legend = pretty.vals, 
-        col = scales::col_factor(col.palette, NULL, na.color = "#FFFFFF")(pretty.vals), 
-        maxColorValue = 255
+        domain = color.levels,
+        na.color = default.color,
+        ordered = TRUE
       )
       
+      
+      # apply color mapping
+      h$.color <- color.mapper(h[[color]])
+      
+      # generate colors and labels for legend
+      pretty.vals <- color.levels
+      color.legend.data <- list(legend = pretty.vals, col = color.mapper(pretty.vals))
+      
     }
   }
   
